# R Book available as pdf:
# Venables, Smith: Introduction to R
# Link: http://cran.r-project.org/doc/manuals/R-intro.pdf

#HELP commands:
#help(...)
#help.search("...")
#R is case sensitive!!!

#----------------------------- Objects in R ------------------------------------
#--- Assignments --- 
x <- 5                                         #store 5 in variable (object) x
y <- 3                                         #store 3 in variable y
z <- x + y                                     #sum of two variables

#--- Vectors ---                               #ordered set of elements of the same type
vec0 <- 1:10                                   #create vector from 1 to 10
vec1 <- c(3,2,7,4,6)                           #create a vector using c
vec2 <- rep(5, times = 10)                     #repeat elements
vec3 <- seq(from = 0, to = 1, by = 0.1)        #generate sequence
vec4 <- sample(0:1, 20, replace = TRUE)        #0,1 random numbers

#subselection of vector elements
vec1[which(vec1>3)]                            #select elements > 3
vec1[3]                                        #select 3rd element
vec1[c(1,5)]                                   #select 1st and 5th element

#---- Matrices ---                             #2-dimensional array of elements of the same type
mat1 <- matrix(1:10, ncol = 2)                 #elements column-wise
mat1 <- matrix(1:10, ncol = 2, byrow = TRUE)   #elements row-wise
mat2 <- t(mat1)                                #transpose
mat1%*%mat2                                    #matrix multiplication

mat1*mat1                                      #Hadamard product

#select elements                               
mat1[1,2]                                      #select element (1,2)
mat1[1,]                                       #select row 1
mat1[,2]                                       #select column 2

#--- Data Frame ---                            #similar to matrix, but different types of variables are possible
df1 <- letters[1:10]                           #letters a...f
df2 <- 1:10                                    #numbers 1 to 10
df12 <- data.frame(df1, df2)                   #concatenate as data frame
df12[5,]                                       #select 5th row

# List                                         #ordered set of components that may have different types; most flexbile data structure
list1 <- list(df1,df2,vec1,mat1)               #list of letters, vectors, matrix
list1[[1]]                                     #select first list element (letters)
list1[[1]][5]                                  #pick out 5th letter

list1[[4]]                                     #select matrix
list1[[4]][4,2]                                #pick out element (4,2)

names(list1) <- c("let","seq","vec","mat")     #label list
list1
list1$mat                                      #instead of list[[4]] (important!!!)
list1$mat[,2]                                  #select 2nd column

#--------------------------------- end objects ---------------------------------


#-------------------------- import/export data ---------------------------------
library(foreign)                                     #import/export package
dataceo <- read.table("dataceo.txt", header = TRUE)  #read txt-file
# In R it is needed to change the directory! Otherwise quote path.
?read.table

#read spss files with and without labels
Cars1 <- read.spss(file = "Cars.sav", to.data.frame = TRUE)   
Cars2 <- read.spss(file = "Cars.sav", to.data.frame = TRUE, use.value.labels = FALSE)   

#excel files can be read with read.csv()

#----------------------------- end import/export -------------------------------

#----------------------- Descriptive statistics and plots ----------------------

#Mean, Variance, standard deviation, Quartiles, Median, Correlation, Covariance,
#Skewness, Curtosis, boxplots, histograms, empricial cumulative distribution function etc.
    
library(MASS)                                  #package for basic statistics
library(scatterplot3d)                         #static 3d-plots
library(rgl)                                   #dynamic 3d-plots

colnames(dataceo)                              #variable names
attach(dataceo)                                #attach variable names
mean(age)                                      #mean
sd(age)                                        #standard deviation
median(age)                                    #median
cor(age, tenure)                               #Pearson correlation


boxplot(age)                                   #boxplots
hist(age)                                      #histogram
plot(age)                                      #plot observation number on x, age on y
plot.ecdf(age)                                 #empirical distribution function
plot(age, tenure)                              #plot age on x and tenure on y

#--- Customize plots ---
#?plot, ?par
#change x and y labels
plot(age, tenure, xlab = "Age CEO data", ylab = "Tenure CEO data")

#add title
plot(age, tenure, xlab = "Age CEO data", ylab = "Tenure CEO data", main = "CEO scatterplot")

#change points
plot(age, tenure, xlab = "Age CEO data", ylab = "Tenure CEO data", main = "CEO scatterplot",
pch = 19)

#change color (blue)
plot(age, tenure, xlab = "Age CEO data", ylab = "Tenure CEO data", main = "CEO scatterplot",
pch = 19, col = 4)

#add horizontal line (dashed) and regression line
plot(age, tenure, xlab = "Age CEO data", ylab = "Tenure CEO data", main = "CEO scatterplot",
pch = 19, col = 4)
abline(a = 10, b = 0, lty = 2, col = "lightgray")
abline(lsfit(age,tenure), col = "red")


# Examples for plots in iris data
data(iris)                                     
attach(iris)
plot(Sepal.Length,Sepal.Width, type = "n")     #scatterplot length vs width (no points)
text(Sepal.Length, Sepal.Width, labels = Species) #label with species
Sys.sleep(4)                                   #"simulation"
image(kde2d(Sepal.Length,Sepal.Width))         #colored image (spatial data)
Sys.sleep(4)
persp(kde2d(Sepal.Length,Sepal.Width))         #perspective plot
Sys.sleep(4)
contour(kde2d(Sepal.Length,Sepal.Width))       #contour plot

# all in 1 device
par(mfrow = c(2,2))                            #open 2 times 2 devices
plot(Sepal.Length,Sepal.Width)                 #scatterplot length vs width  
image(kde2d(Sepal.Length,Sepal.Width))         #colored image (spatial data)
persp(kde2d(Sepal.Length,Sepal.Width))         #perspective plot
contour(kde2d(Sepal.Length,Sepal.Width))       #contour plot

plot3d(Sepal.Length, Sepal.Width, Petal.Width, size = 4)

#--------------------- end descriptive analysis/plots --------------------------


#------------------------------------ LLBT -------------------------------------

library(prefmod)
library(gnm)
?prefmod

# fit LLBT with an undecided category
data(cemspc)
mfr<-llbt.design(cemspc,nitems=6,objnames=c("lo","pa","mi","sg","ba","st"))
res2 <- gnm(y ~ lo + pa + mi + sg + ba +st + g1, eliminate = mu, data = mfr, family = poisson)
summary(res2)

names(res2)
dev2 <- round(res2$deviance, digits = 4)
df2 <- res2$df.residual
prob2 <- 1 - pchisq(dev2, df2)
print(prob2)

print(res2$coefficients[16:21])
res2$coefficients[21] <- 0
worth <- round(exp(2*res2$coefficients[16:21])/(sum(exp(2 * res2$coefficients[16:21]))), digits = 4)
names(worth)  <- c("lo","pa","mi","sg","ba","st")
print(worth)

#---------------------------------- end LLBT -----------------------------------
